@@ -10,7 +10,14 @@ from microannotate import viewer
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser()
-    parser.add_argument("repository_dir", help="Path to the repository", action="store")
+    parser.add_argument(
+        "repository_dir", help="Path to the input repository", action="store"
+    )
+    parser.add_argument(
+        "microannotated_repository_dir",
+        help="Path to the microannotated repository",
+        action="store",
+    )
     parser.add_argument(
         "path", help="Path to the file in the repository", action="store"
     )
@@ -19,4 +26,8 @@ if __name__ == "__main__":
     )
     args = parser.parse_args()
 
-    print(viewer.html(args.repository_dir, args.rev, args.path))
+    print(
+        viewer.html(
+            args.repository_dir, args.microannotated_repository_dir, args.rev, args.path
+        )
+    )
